@@ -9,7 +9,7 @@ our %EXPORT_TAGS = ( 'all' => [ ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 our %avg_counters;
 our %bulk;
@@ -38,6 +38,8 @@ Graphite::Simple - Perl XS package provides methods to collect metrics and send
 
   $graphite->disconnect();
 
+  $graphite->is_connected();
+
   my $bulk = $graphite->get_bulk_metrics();
 
   my $status = $graphite->send_bulk();
@@ -100,11 +102,20 @@ In this case you can use C<send_bulk_delegate> method to do this work by other c
 Sets the path to the Unix socket file.
 Either C<path> or C<host>/C<port> can be used.
 
+=item use_stream_sock
+
+By default value is false.
+
+If true, then enables SOCK_STREAM for Unix Socks.
+Otherwise SOCK_DGRAM (UDP) will be used.
+
 =item host
 
 Sets the hostname or IPv4 address of Graphite server.
 This option is mandatory if C<enabled> is true.
 
+In this case SOCK_DGRAM (UDP) will be used.
+
 =item port
 
 Sets the port number of Graphite server.
@@ -168,6 +179,11 @@ Returns 1 in case of success, otherwise returns 0.
 
 Closes the connection.
 
+=head2 $self->is_connected()
+
+Returns 1 or 0.
+It returns 0 only in cases if C<connected> isn't invoked or Unix Sock connection is broken.
+
 =head2 $self->send_bulk_delegate()
 
 Calculates the result metrics and passes them to specified method in C<sender_name>.
